# SQL Dialects

This module contains query builder classes for specific SQL dialects.

::: neopika.dialects
    handler: python
    options:
      members: true
      show_root_heading: false
      show_source: true
      heading_level: 2 